pub fn encode_map<V: Serialize>( input: &BTreeMap<KeyString, V>, ) -> Result<String, EncodingError>
Serialize the input value map into a logfmt string.
Returns an EncodingError if any of the keys are not strings.
EncodingError